@@ -16,12 +16,14 @@ import Control.Exception (SomeException(..), AsyncException(..))
 import qualified Control.Exception as E
 import Data.ByteString.Builder (byteString)
 import Data.IORef
+import qualified Data.Vault.Lazy as Vault
 import Network.HPACK
 import Network.HPACK.Token
 import qualified Network.HTTP.Types as H
 import Network.HTTP2
 import Network.HTTP2.Priority
 import Network.Wai
+import qualified Network.Wai.Handler.Warp.Timeout as Timeout
 import Network.Wai.Internal (Response(..), ResponseReceived(..), ResponseReceived(..))
 
 import Network.Wai.Handler.Warp.FileInfoCache
@@ -31,6 +33,7 @@ import Network.Wai.Handler.Warp.HTTP2.Manager
 import Network.Wai.Handler.Warp.HTTP2.Request
 import Network.Wai.Handler.Warp.HTTP2.Types
 import Network.Wai.Handler.Warp.Imports hiding (insert)
+import Network.Wai.Handler.Warp.Request (pauseTimeoutKey)
 import qualified Network.Wai.Handler.Warp.Response as R
 import qualified Network.Wai.Handler.Warp.Settings as S
 import qualified Network.Wai.Handler.Warp.Timeout as T
@@ -219,8 +222,9 @@ response settings ctx@Context{outputQ} mgr ii reqvt tconf strm req rsp = case rs
             !out = Output strm rspn ii tell h2data rspnOrWait
         enqueueOutput outputQ out
         let push b = do
+              T.pause th
               atomically $ writeTBQueue tbq (SBuilder b)
-              T.tickle th
+              T.resume th
             flush  = atomically $ writeTBQueue tbq SFlush
         _ <- strmbdy push flush
         atomically $ writeTBQueue tbq SFinish
@@ -242,7 +246,16 @@ worker ctx@Context{inputQ,controlQ} set app responder tm = do
             setStreamInfo sinfo inp
             T.resume th
             T.tickle th
-            app req $ responder ii reqvt tcont strm req
+            let !ii' = ii { threadHandle = th }
+                !body = requestBody req
+                !body' = do
+                    T.pause th
+                    bs <- body
+                    T.resume th
+                    return bs
+                !vaultValue = Vault.insert pauseTimeoutKey (Timeout.pause th) $ vault req
+                !req' = req { vault = vaultValue, requestBody = body' }
+            app req' $ responder ii' reqvt tcont strm req'
         cont1 <- case ex of
             Right ResponseReceived -> return True
             Left  e@(SomeException _)
